@@ -36,6 +36,7 @@
 "*mitSaverExtension:	False",
 "*xidleExtension:	True",
 "*procInterrupts:	True",
+"GetViewPortIsFullOfLies: False",
 "*demoCommand: xscreensaver-demo",
 "*prefsCommand: xscreensaver-demo -prefs",
 "*helpURL: http://www.jwz.org/xscreensaver/man.html",
@@ -48,7 +49,7 @@
 	   \"Qix (transparent)\" 	qix -root -count 4 -solid -transparent	    \\n\
 		\"Qix (linear)\" 	qix -root -count 5 -solid -transparent	      \
 				  -linear -segments 250 -size 100	    \\n\
-- mono: 	   \"Qix (xor)\" 	qix -root -linear -count 5 -size 200	      \
+-		   \"Qix (xor)\" 	qix -root -linear -count 5 -size 200	      \
 				  -spread 30 -segments 75 -solid -xor	    \\n\
 									      \
 	  \"Attraction (balls)\" 	attraction -root -mode balls		    \\n\
@@ -84,13 +85,13 @@
 				maze -root				    \\n\
 				noseguy -root				    \\n\
 				flame -root				    \\n\
-				lmorph -root				    \\n\
+-				lmorph -root				    \\n\
 				deco -root				    \\n\
 				moire -root				    \\n\
 				moire2 -root				    \\n\
 				lightning -root				    \\n\
 				strange -root				    \\n\
-				spiral -root				    \\n\
+-				spiral -root				    \\n\
 				laser -root				    \\n\
 				grav -root				    \\n\
 	       \"Grav (trails)\" 	grav -root -trail -decay		    \\n\
@@ -98,7 +99,7 @@
 				ifs -root				    \\n\
 				julia -root				    \\n\
 				penrose -root				    \\n\
-				sierpinski -root			    \\n\
+-				sierpinski -root			    \\n\
 				braid -root				    \\n\
 				galaxy -root				    \\n\
 				bouboule -root				    \\n\
@@ -106,23 +107,24 @@
 				flag -root				    \\n\
 				sphere -root				    \\n\
 				forest -root				    \\n\
-				lisa -root				    \\n\
-				lissie -root				    \\n\
+-				lisa -root				    \\n\
+-				lissie -root				    \\n\
 				goop -root -max-velocity 0.5 -elasticity      \
 				  0.9					    \\n\
 				starfish -root				    \\n\
 	     \"Starfish (blob)\" 	starfish -root -blob			    \\n\
 				munch -root				    \\n\
+				mismunch -root				    \\n\
 				fadeplot -root				    \\n\
 				coral -root -delay 0			    \\n\
 				mountain -root				    \\n\
 				triangle -root -delay 1			    \\n\
-				worm -root				    \\n\
-				rotor -root				    \\n\
-				ant -root				    \\n\
-				demon -root				    \\n\
-				loop -root				    \\n\
-				vines -root				    \\n\
+-				worm -root				    \\n\
+-				rotor -root				    \\n\
+-				ant -root				    \\n\
+-				demon -root				    \\n\
+-				loop -root				    \\n\
+-				vines -root				    \\n\
 				kaleidescope -root			    \\n\
 				xjack -root				    \\n\
 				xlyap -root -randomize			    \\n\
@@ -147,7 +149,7 @@
 				wander -root				    \\n\
 	      \"Wander (spots)\" 	wander -root -advance 0 -size 10 -circles     \
 				  -length 10000 -reset 100000		    \\n\
-				critical -root				    \\n\
+-				critical -root				    \\n\
 				phosphor -root				    \\n\
 				xmatrix -root				    \\n\
 				petri -root -size 2 -count 20		    \\n\
@@ -160,6 +162,7 @@
 				blaster -root				    \\n\
 				bumps -root				    \\n\
 				xteevee -root				    \\n\
+				xanalogtv -root				    \\n\
 				xspirograph -root			    \\n\
 				nerverot -root				    \\n\
 -	    \"NerveRot (dense)\"	nerverot -root -count 1000		    \\n\
@@ -193,7 +196,19 @@
  	                	barcode -root				    \\n\
  	                	piecewise -root				    \\n\
  	                	cloudlife -root				    \\n\
-  color: 			bubbles -root				    \\n\
+		   \"FontGlide\"	fontglide -root -page			    \\n\
+	\"FontGlide (scroller)\"	fontglide -root -scroll			    \\n\
+				apple2 -root				    \\n\
+                                bubbles -root				    \\n\
+				pong -root				    \\n\
+				wormhole -root				    \\n\
+				pacman -root				    \\n\
+				fuzzyflakes -root			    \\n\
+				anemotaxis -root			    \\n\
+				memscroller -root			    \\n\
+				substrate -root				    \\n\
+				intermomentary -root			    \\n\
+				fireworkx -root				    \\n\
 - default-n:			webcollage -root			    \\n\
 - default-n:  \"WebCollage (whacked)\"					      \
 				webcollage -root -filter		      \
@@ -210,7 +225,7 @@
 	   GL:			pipes -root				    \\n\
 	   GL:			sproingies -root			    \\n\
 	   GL:			rubik -root				    \\n\
-	   GL:			atlantis -root				    \\n\
+	   GL:			atlantis -root -gradient		    \\n\
 	   GL:			lament -root				    \\n\
 	   GL:			bubble3d -root				    \\n\
 	   GL:			glplanet -root				    \\n\
@@ -236,9 +251,9 @@
 	   GL:			flipscreen3d -root			    \\n\
 	   GL:			glsnake -root				    \\n\
 	   GL:			boxed -root				    \\n\
-	   GL:			glforestfire -root			    \\n\
--	   GL:			glforestfire -root -rain		    \\n\
-	   GL:			sballs -root				    \\n\
+-	   GL:	\"GLForestFire\"		glforestfire -root		    \\n\
+-	   GL:	\"GLForestFire (rain)\"	glforestfire -root -count 0	    \\n\
+-	   GL:			sballs -root				    \\n\
 	   GL:			cubenetic -root				    \\n\
 	   GL:			spheremonics -root			    \\n\
 	   GL:			lavalite -root				    \\n\
@@ -250,23 +265,35 @@
 	   GL:			bouncingcow -root			    \\n\
 	   GL:			jigglypuff -root -random		    \\n\
 	   GL:			klein -root -random			    \\n\
-	   GL:	\"HyperTorus (striped)\"	hypertorus -root		    \\n\
-	   GL:	\"HyperTorus (solid)\"	hypertorus -root -solid -transp	    \\n\
+	   GL:	\"HyperTorus (striped)\" hypertorus -root			    \\n\
+	   GL:	\"HyperTorus (solid)\"   hypertorus -root -solid -transparent \\n\
 	   GL:			glmatrix -root				    \\n\
 	   GL:			cubestorm -root				    \\n\
 	   GL:			glknots -root				    \\n\
 	   GL:			blocktube -root				    \\n\
 	   GL:			flipflop -root				    \\n\
 	   GL:			antspotlight -root			    \\n\
-	   GL:			polytopes -root				    \\n\
 -	   GL:			glslideshow -root			    \\n\
+	   GL:			polytopes -root				    \\n\
+	   GL:			gleidescope -root			    \\n\
+- 	   GL:			mirrorblob -root			    \\n\
+	   GL:	    \"MirrorBlob (color only)\"				      \
+                                mirrorblob -root -colour -no-texture	    \\n\
+	   GL:			blinkbox -root				    \\n\
+	   GL:			noof -root				    \\n\
+	   GL:			polyhedra -root				    \\n\
+-	   GL:                  antinspect -root                            \\n\
+	   GL:			providence -root			    \\n\
+	   GL:	\"Pinion (large gears)\"	pinion -root			    \\n\
+	   GL:	\"Pinion (small gears)\"	pinion -root -size 0.2		    \\n\
+	   GL:			pinion -root				    \\n\
 									      \
 -				xdaliclock -root -builtin3 -cycle	    \\n\
 - default-n:			xearth -nofork -nostars -ncolors 50	      \
 				  -night 3 -wait 0 -timewarp 400.0 -pos	      \
 				  sunrel/38/-30				    \\n\
--				xplanetbg -xscreensaver -moonside             \
-                                  -markerfile earth -wait 1 -timewarp 400   \\n\
+-				xplanet -vroot -wait 1 -timewarp 90000        \
+                                  -label -origin moon			    \\n\
 -				xmountains -b -M -Z 0 -r 1		    \\n\
 -	\"XMountains (top)\"	xmountains -b -M -Z 0 -r 1 -m		    \\n\
 -                               xaos -root -autopilot -nogui -delay 10000     \
@@ -310,7 +337,7 @@
 "*passwd.passwdFont:		*-courier-medium-r-*-*-*-140-*-*-*-iso8859-1",
 "*passwd.thermometer.width:	8",
 "*splash.heading.label:		XScreenSaver %s",
-"*splash.body.label:		Copyright  1991-2002 by",
+"*splash.body.label:		Copyright  1991-2004 by",
 "*splash.body2.label:		Jamie Zawinski <jwz@jwz.org>",
 "*splash.demo.label:		Settings",
 "*splash.help.label:		Help",
@@ -435,6 +462,7 @@
 "*hacks.shadebobs.name:      ShadeBobs",
 "*hacks.ccurve.name:         C Curve",
 "*hacks.xteevee.name:        XTeeVee",
+"*hacks.xanalogtv.name:      XAnalogTV",
 "*hacks.xspirograph.name:    XSpiroGraph",
 "*hacks.nerverot.name:       NerveRot",
 "*hacks.webcollage.name:     WebCollage",
@@ -455,6 +483,7 @@
 "*hacks.sballs.name:         SBalls",
 "*hacks.xdaliclock.name:     XDaliClock",
 "*hacks.xplanetbg.name:      XPlanet",
+"*hacks.xplanet.name:        XPlanet",
 "*hacks.xaos.name:           XaoS",
 "*hacks.xfishtank.name:      XFishTank",
 "*hacks.electricsheep.name:  ElectricSheep",
@@ -468,4 +497,9 @@
 "*hacks.blocktube.name:      BlockTube",
 "*hacks.flipflop.name:       FlipFlop",
 "*hacks.antspotlight.name:   AntSpotlight",
+"*hacks.fontglide.name:      FontGlide",
+"*hacks.mirrorblob.name:     MirrorBlob",
+"*hacks.blinkbox.name:       BlinkBox",
+"*hacks.fuzzyflakes.name:    FuzzyFlakes",
+"*hacks.memscroller.name:    MemScroller",
 "*hacks.documentation.isInstalled: True",
