@@ -1,4 +1,4 @@
-/* xscreensaver, Copyright (c) 1993-2003 Jamie Zawinski <jwz@jwz.org>
+/* xscreensaver, Copyright (c) 1993-2004 Jamie Zawinski <jwz@jwz.org>
  *
  * Permission to use, copy, modify, distribute, and sell this software and its
  * documentation for any purpose is hereby granted without fee, provided that
@@ -80,6 +80,10 @@ struct saver_info {
   int sgi_saver_ext_event_number;
   int sgi_saver_ext_error_number;
 # endif
+# ifdef HAVE_RANDR
+  int randr_event_number;
+  int randr_error_number;
+# endif
 
 
   /* =======================================================================
@@ -93,7 +97,9 @@ struct saver_info {
   int keyboard_grab_screen;	/* The screen number the keyboard grab is on */
   Bool fading_possible_p;	/* Whether fading to/from black is possible. */
   Bool throttled_p;             /* Whether we should temporarily just blank
-                                   the screen, not run hacks. */
+                                   the screen, not run hacks. (Deprecated:
+                                   users should use "xset dpms force off"
+                                   instead.) */
   time_t blank_time;		/* The time at which the screen was blanked
                                    (if currently blanked) or unblanked (if
                                    not blanked.) */
@@ -153,6 +159,9 @@ struct saver_info {
   XtIntervalId watchdog_id;	/* Timer to implement `prefs.watchdog */
   XtIntervalId check_pointer_timer_id;	/* `prefs.pointer_timeout' */
 
+  XtIntervalId de_race_id;	/* Timer to make sure screen un-blanks */
+  int de_race_ticks;
+
   time_t last_activity_time;		   /* Used only when no server exts. */
   time_t last_wall_clock_time;             /* Used to detect laptop suspend. */
   saver_screen_info *last_activity_screen;
@@ -299,6 +308,9 @@ extern Bool query_sgi_saver_extension (saver_info *);
 #ifdef HAVE_XIDLE_EXTENSION
 extern Bool query_xidle_extension (saver_info *);
 #endif
+#ifdef HAVE_RANDR
+extern Bool query_randr_extension (saver_info *);
+#endif
 #ifdef HAVE_PROC_INTERRUPTS
 extern Bool query_proc_interrupts_available (saver_info *, const char **why);
 #endif
@@ -318,6 +330,7 @@ extern void raise_window (saver_info *si,
 			    Bool dont_clear);
 extern Bool blank_screen (saver_info *si);
 extern void unblank_screen (saver_info *si);
+extern void resize_screensaver_window (saver_info *si);
 
 extern void get_screen_viewport (saver_screen_info *ssi,
                                  int *x_ret, int *y_ret,
@@ -375,8 +388,11 @@ extern void cycle_timer (XtPointer si, XtIntervalId *id);
 extern void activate_lock_timer (XtPointer si, XtIntervalId *id);
 extern void reset_watchdog_timer (saver_info *si, Bool on_p);
 extern void idle_timer (XtPointer si, XtIntervalId *id);
+extern void de_race_timer (XtPointer si, XtIntervalId *id);
 extern void sleep_until_idle (saver_info *si, Bool until_idle_p);
 extern void reset_timers (saver_info *si);
+extern void schedule_wakeup_event (saver_info *si, Time when, Bool verbose_p);
+
 
 /* =======================================================================
    remote control
