@@ -91,24 +91,24 @@ static XrmOptionDescRec opts[] = {
   {"-parts", ".circuit.parts", XrmoptionSepArg, "10" },
   {"-font", ".circuit.font", XrmoptionSepArg, "fixed" },
   {"-rotate-speed", ".circuit.rotatespeed", XrmoptionSepArg, "1" },
-  {"+spin", ".circuit.spin", XrmoptionNoArg, (caddr_t) "false" },
-  {"-spin", ".circuit.spin", XrmoptionNoArg, (caddr_t) "true" },
-  {"+light", ".circuit.light", XrmoptionNoArg, (caddr_t) "false" },
-  {"-light", ".circuit.light", XrmoptionNoArg, (caddr_t) "true" },
-  {"+seven", ".circuit.seven", XrmoptionNoArg, (caddr_t) "false" },
-  {"-seven", ".circuit.seven", XrmoptionNoArg, (caddr_t) "true" },
-  {"+rotate", ".circuit.rotate", XrmoptionNoArg, (caddr_t) "false" },
-  {"-rotate", ".circuit.rotate", XrmoptionNoArg, (caddr_t) "true" },
+  {"+spin", ".circuit.spin", XrmoptionNoArg, "false" },
+  {"-spin", ".circuit.spin", XrmoptionNoArg, "true" },
+  {"+light", ".circuit.light", XrmoptionNoArg, "false" },
+  {"-light", ".circuit.light", XrmoptionNoArg, "true" },
+  {"+seven", ".circuit.seven", XrmoptionNoArg, "false" },
+  {"-seven", ".circuit.seven", XrmoptionNoArg, "true" },
+  {"+rotate", ".circuit.rotate", XrmoptionNoArg, "false" },
+  {"-rotate", ".circuit.rotate", XrmoptionNoArg, "true" },
 };
 
 static argtype vars[] = {
-  {(caddr_t *) &maxparts, "parts", "Parts", DEF_PARTS, t_Int},
-  {(caddr_t *) &font, "font", "Font", "fixed", t_String},
-  {(caddr_t *) &rotatespeed, "rotatespeed", "Rotatespeed", "1", t_Int},
-  {(caddr_t *) &spin, "spin", "Spin", DEF_SPIN, t_Bool},
-  {(caddr_t *) &rotate, "rotate", "Rotate", "False", t_Bool},
-  {(caddr_t *) &uselight, "light", "Light", "True", t_Bool},
-  {(caddr_t *) &seven, "seven", "Seven", DEF_SEVEN, t_Bool},
+  {&maxparts, "parts", "Parts", DEF_PARTS, t_Int},
+  {&font, "font", "Font", "fixed", t_String},
+  {&rotatespeed, "rotatespeed", "Rotatespeed", "1", t_Int},
+  {&spin, "spin", "Spin", DEF_SPIN, t_Bool},
+  {&rotate, "rotate", "Rotate", "False", t_Bool},
+  {&uselight, "light", "Light", "True", t_Bool},
+  {&seven, "seven", "Seven", DEF_SEVEN, t_Bool},
 };
 
 ModeSpecOpt circuit_opts = {countof(opts), opts, countof(vars), vars, NULL};
@@ -149,7 +149,7 @@ static int YMAX = 30;
 
 #define MAX_COMPONENTS 30
 
-#define MOVE_MULT 0.05
+#define MOVE_MULT 0.02
 
 static float f_rand(void) {
    return ((float)RAND(10000)/(float)10000);
@@ -1498,7 +1498,7 @@ Component * NewComponent(void)
   c->rotx = f_rand();
   c->roty = f_rand();
   c->rotz = f_rand();
-  c->drot = f_rand() * 7;
+  c->drot = f_rand() * 3;
   c->rdeg = 0;
   c->dz = f_rand()*2 - 1;
   c->norm = 0;
