@@ -1,4 +1,4 @@
-/* flyingtoasters, Copyright (c) 2003 Jamie Zawinski <jwz@jwz.org>
+/* flyingtoasters, Copyright (c) 2003, 2004 Jamie Zawinski <jwz@jwz.org>
  *
  * Permission to use, copy, modify, distribute, and sell this software and its
  * documentation for any purpose is hereby granted without fee, provided that
@@ -153,15 +153,15 @@ static XrmOptionDescRec opts[] = {
   { "-speed",  ".speed",  XrmoptionSepArg, 0 },
   { "-ntoasters",  ".ntoasters", XrmoptionSepArg, 0 },
   { "-nslices",    ".nslices",   XrmoptionSepArg, 0 },
-  {"-texture",     ".texture",   XrmoptionNoArg, (caddr_t) "True" },
-  {"+texture",     ".texture",   XrmoptionNoArg, (caddr_t) "False" },
+  {"-texture",     ".texture",   XrmoptionNoArg, "True" },
+  {"+texture",     ".texture",   XrmoptionNoArg, "False" },
 };
 
 static argtype vars[] = {
-  {(caddr_t *) &speed,      "speed",      "Speed",   DEF_SPEED,     t_Float},
-  {(caddr_t *) &ntoasters,  "ntoasters",  "Count",   DEF_NTOASTERS, t_Int},
-  {(caddr_t *) &nslices,    "nslices",    "Count",   DEF_NSLICES,   t_Int},
-  {(caddr_t *) &do_texture, "texture",    "Texture", DEF_TEXTURE,   t_Bool},
+  {&speed,      "speed",      "Speed",   DEF_SPEED,     t_Float},
+  {&ntoasters,  "ntoasters",  "Count",   DEF_NTOASTERS, t_Int},
+  {&nslices,    "nslices",    "Count",   DEF_NSLICES,   t_Int},
+  {&do_texture, "texture",    "Texture", DEF_TEXTURE,   t_Bool},
 };
 
 ModeSpecOpt sws_opts = {countof(opts), opts, countof(vars), vars, NULL};
