@@ -1,4 +1,4 @@
-/* gltext, Copyright (c) 2001, 2002, 2003 Jamie Zawinski <jwz@jwz.org>
+/* gltext, Copyright (c) 2001, 2002, 2003, 2004 Jamie Zawinski <jwz@jwz.org>
  *
  * Permission to use, copy, modify, distribute, and sell this software and its
  * documentation for any purpose is hereby granted without fee, provided that
@@ -25,7 +25,7 @@ extern XtAppContext app;
 #define DEF_SPIN        "XYZ"
 #define DEF_WANDER      "True"
 
-#define DEFAULTS	"*delay:	10000       \n" \
+#define DEFAULTS	"*delay:	20000       \n" \
 			"*showFPS:      False       \n" \
 			"*wireframe:    False       \n" \
 			"*spin:       " DEF_SPIN   "\n" \
@@ -54,6 +54,10 @@ extern XtAppContext app;
 #include <sys/time.h>
 #include <ctype.h>
 
+#ifdef HAVE_LOCALE_H
+# include <locale.h>
+#endif /* HAVE_LOCALE_H */
+
 #ifdef USE_GL /* whole file */
 
 #ifdef HAVE_UNAME
@@ -98,9 +102,9 @@ static XrmOptionDescRec opts[] = {
 };
 
 static argtype vars[] = {
-  {(caddr_t *) &text_fmt,  "text",   "Text",   DEF_TEXT,   t_String},
-  {(caddr_t *) &do_spin,   "spin",   "Spin",   DEF_SPIN,   t_String},
-  {(caddr_t *) &do_wander, "wander", "Wander", DEF_WANDER, t_Bool},
+  {&text_fmt,  "text",   "Text",   DEF_TEXT,   t_String},
+  {&do_spin,   "spin",   "Spin",   DEF_SPIN,   t_String},
+  {&do_wander, "wander", "Wander", DEF_WANDER, t_Bool},
 };
 
 ModeSpecOpt sws_opts = {countof(opts), opts, countof(vars), vars, NULL};
@@ -152,6 +156,32 @@ gl_init (ModeInfo *mi)
 }
 
 
+/* The GLUT font only has ASCII characters in them, so do what we can to
+   convert Latin1 characters to the nearest ASCII equivalent... 
+ */
+static void
+latin1_to_ascii (char *s)
+{
+  unsigned char *us = (unsigned char *) s;
+  const unsigned char ascii[95] = {
+    '!', 'C', '#', '#', 'Y', '|', 'S', '_', 'C', '?', '<', '=', '-', 'R', '_',
+    '?', '?', '2', '3', '\'','u', 'P', '.', ',', '1', 'o', '>', '?', '?', '?',
+    '?', 'A', 'A', 'A', 'A', 'A', 'A', 'E', 'C', 'E', 'E', 'E', 'E', 'I', 'I',
+    'I', 'I', 'D', 'N', 'O', 'O', 'O', 'O', 'O', 'x', '0', 'U', 'U', 'U', 'U',
+    'Y', 'p', 'S', 'a', 'a', 'a', 'a', 'a', 'a', 'e', 'c', 'e', 'e', 'e', 'e',
+    'i', 'i', 'i', 'i', 'o', 'n', 'o', 'o', 'o', 'o', 'o', '/', 'o', 'u', 'u',
+    'u', 'u', 'y', 'p', 'y' };
+  while (*us)
+    {
+      if (*us >= 161)
+        *us = ascii[*us - 161];
+      else if (*us > 127)
+        *us = '?';
+      us++;
+    }
+}
+
+
 static void
 parse_text (ModeInfo *mi)
 {
@@ -211,6 +241,8 @@ parse_text (ModeInfo *mi)
       if (!*tp->text)
         sprintf (tp->text, "strftime error:\n%s", text_fmt);
     }
+
+  latin1_to_ascii (tp->text);
 }
 
 
@@ -253,6 +285,10 @@ init_text (ModeInfo *mi)
   text_configuration *tp;
   int i;
 
+# ifdef HAVE_SETLOCALE
+  setlocale (LC_TIME, "");      /* for strftime() calls */
+# endif
+
   if (!tps) {
     tps = (text_configuration *)
       calloc (MI_NUM_SCREENS(mi), sizeof (text_configuration));
@@ -273,9 +309,9 @@ init_text (ModeInfo *mi)
 
   {
     Bool spinx=False, spiny=False, spinz=False;
-    double spin_speed   = 1.0;
-    double wander_speed = 0.05;
-    double spin_accel   = 1.0;
+    double spin_speed   = 0.5;
+    double wander_speed = 0.02;
+    double spin_accel   = 0.5;
 
     char *s = do_spin;
     while (*s)
@@ -389,9 +425,9 @@ text_extents (const char *string, int *wP, int *hP)
 
         if (w > *wP) *wP = w;
         *hP += line_height;
-        s++;
         lines++;
         if (*s == 0) break;
+        s++;
       }
     else
       s++;
