@@ -171,39 +171,33 @@ static const float offset3d[4] = {
 static XrmOptionDescRec opts[] =
 {
   {"-mesh",            ".hypertorus.displayMode",  XrmoptionNoArg,
-                       (caddr_t)DISP_WIREFRAME_STR },
+                       DISP_WIREFRAME_STR },
   {"-surface",         ".hypertorus.displayMode",  XrmoptionNoArg,
-                       (caddr_t)DISP_SURFACE_STR },
+                       DISP_SURFACE_STR },
   {"-transparent",     ".hypertorus.displayMode",  XrmoptionNoArg,
-                       (caddr_t)DISP_TRANSPARENT_STR },
+                       DISP_TRANSPARENT_STR },
   {"-solid",           ".hypertorus.appearance",   XrmoptionNoArg,
-                       (caddr_t)APPEARANCE_SOLID_STR },
+                       APPEARANCE_SOLID_STR },
   {"-bands",           ".hypertorus.appearance",   XrmoptionNoArg,
-                       (caddr_t)APPEARANCE_BANDS_STR },
+                       APPEARANCE_BANDS_STR },
   {"-twosided",        ".hypertorus.colors",       XrmoptionNoArg,
-                       (caddr_t)COLORS_TWOSIDED_STR },
+                       COLORS_TWOSIDED_STR },
   {"-colorwheel",      ".hypertorus.colors",       XrmoptionNoArg,
-                       (caddr_t)COLORS_COLORWHEEL_STR },
+                       COLORS_COLORWHEEL_STR },
   {"-perspective-3d",  ".hypertorus.projection3d", XrmoptionNoArg,
-                       (caddr_t)DISP_3D_PERSPECTIVE_STR },
+                       DISP_3D_PERSPECTIVE_STR },
   {"-orthographic-3d", ".hypertorus.projection3d", XrmoptionNoArg,
-                       (caddr_t)DISP_3D_ORTHOGRAPHIC_STR },
+                       DISP_3D_ORTHOGRAPHIC_STR },
   {"-perspective-4d",  ".hypertorus.projection4d", XrmoptionNoArg,
-                       (caddr_t)DISP_4D_PERSPECTIVE_STR },
+                       DISP_4D_PERSPECTIVE_STR },
   {"-orthographic-4d", ".hypertorus.projection4d", XrmoptionNoArg,
-                       (caddr_t)DISP_4D_ORTHOGRAPHIC_STR },
-  {"-speed-wx",        ".hypertorus.speedwx",      XrmoptionSepArg,
-                       (caddr_t)NULL },
-  {"-speed-wy",        ".hypertorus.speedwy",      XrmoptionSepArg,
-                       (caddr_t)NULL },
-  {"-speed-wz",        ".hypertorus.speedwz",      XrmoptionSepArg,
-                       (caddr_t)NULL },
-  {"-speed-xy",        ".hypertorus.speedxy",      XrmoptionSepArg,
-                       (caddr_t)NULL },
-  {"-speed-xz",        ".hypertorus.speedxz",      XrmoptionSepArg,
-                       (caddr_t)NULL },
-  {"-speed-yz",        ".hypertorus.speedyz",      XrmoptionSepArg,
-                       (caddr_t)NULL }
+                       DISP_4D_ORTHOGRAPHIC_STR },
+  {"-speed-wx",        ".hypertorus.speedwx",      XrmoptionSepArg, 0 },
+  {"-speed-wy",        ".hypertorus.speedwy",      XrmoptionSepArg, 0 },
+  {"-speed-wz",        ".hypertorus.speedwz",      XrmoptionSepArg, 0 },
+  {"-speed-xy",        ".hypertorus.speedxy",      XrmoptionSepArg, 0 },
+  {"-speed-xz",        ".hypertorus.speedxz",      XrmoptionSepArg, 0 },
+  {"-speed-yz",        ".hypertorus.speedyz",      XrmoptionSepArg, 0 }
 };
 
 static argtype vars[] =
